.. _usage:

Usage
#######################################################################

.. _quickview:

Overview
***********************************************************************

.. develop some entry notes [CHANGE THIS]:

For casual users, the installation instructions allow quick setup and testing of basic functionality.
Additional resources, including example Jupyter notebooks and live interactive versions,
are available to explore features and usage patterns in detail.

.. seealso::

   For those who want to contribute, see :ref:`Development <development>`


.. _installation:

Installation
***********************************************************************

.. develop installation instructions [CHANGE THIS]:

For causal users, install ``babilonia`` to a Python 3 environment via terminal:


.. code-block:: console

    python -m pip install git+https://github.com/iporepos/babilonia.git@main

Installation
***********************************************************************

Install as a Python package
============================================

For Python regular users, install the latest package deploy
to a Python 3 environment via pip:

.. code-block:: console

    python -m pip install babilonia

Or any desired branch or version via github url:

.. code-block:: console

    python -m pip install git+https://github.com/iporepos/babilonia.git@main


.. _guides:

Guides
***********************************************************************

.. develop guiding instructions [CHANGE THIS]:

Develop guide

.. develop guiding resources here [CHANGE THIS]:

Examples
============================================

Develop examples here

